==> manaplus-1.2.1.22.tar.bz2: manaplus-1.2.1.22/src/net/manaserv/adminhandler.cpp <==
/*
 *  The ManaPlus Client
 *  Copyright (C) 2004-2009  The Mana World Development Team
 *  Copyright (C) 2009-2010  The Mana Developers
 *  Copyright (C) 2011-2012  The ManaPlus Developers
 *
 *  This file is part of The ManaPlus Client.
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#include "net/manaserv/adminhandler.h"

#include "net/manaserv/connection.h"
#include "net/manaserv/messageout.h"
#include "net/manaserv/protocol.h"

#include "debug.h"

extern Net::AdminHandler *adminHandler;

namespace ManaServ
{

extern Connection *chatServerConnection;

AdminHandler::AdminHandler()
{
    adminHandler = this;
}

void AdminHandler::announce(const std::string &text)
{
    MessageOut msg(PCMSG_ANNOUNCE);
    msg.writeString(text);
    chatServerConnection->send(msg);
}

void AdminHandler::localAnnounce(const std::string &text A_UNUSED)
{
    // TODO
}

void AdminHandler::hide(bool hide A_UNUSED)
{
    // TODO
}

void AdminHandler::kick(int playerId A_UNUSED)
{
    // TODO
}

void AdminHandler::kick(const std::string &name A_UNUSED)
{
    // TODO
}

void AdminHandler::ban(int playerId A_UNUSED)
{
    // TODO
}

void AdminHandler::ban(const std::string &name A_UNUSED)
{
    // TODO
}

void AdminHandler::unban(int playerId A_UNUSED)
{
    // TODO
}

void AdminHandler::unban(const std::string &name A_UNUSED)
{
    // TODO
}

void AdminHandler::mute(int playerId A_UNUSED, int type A_UNUSED,
                        int limit A_UNUSED)
{
    // TODO
}

void AdminHandler::warp(std::string map A_UNUSED,
                        int x A_UNUSED, int y A_UNUSED)
{
    // TODO
}

} // namespace ManaServ

==> manaplus-1.2.2.19.tar.bz2: manaplus-1.2.2.19/src/net/manaserv/adminhandler.cpp <==
/*
 *  The ManaPlus Client
 *  Copyright (C) 2004-2009  The Mana World Development Team
 *  Copyright (C) 2009-2010  The Mana Developers
 *  Copyright (C) 2011-2012  The ManaPlus Developers
 *
 *  This file is part of The ManaPlus Client.
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#include "net/manaserv/adminhandler.h"

#include "net/manaserv/connection.h"
#include "net/manaserv/messageout.h"
#include "net/manaserv/protocol.h"

#include "debug.h"

extern Net::AdminHandler *adminHandler;

namespace ManaServ
{

extern Connection *chatServerConnection;

AdminHandler::AdminHandler()
{
    adminHandler = this;
}

void AdminHandler::announce(const std::string &text)
{
    MessageOut msg(PCMSG_ANNOUNCE);
    msg.writeString(text);
    chatServerConnection->send(msg);
}

void AdminHandler::localAnnounce(const std::string &text A_UNUSED)
{
    // TODO
}

void AdminHandler::hide(bool hide A_UNUSED)
{
    // TODO
}

void AdminHandler::kick(int playerId A_UNUSED)
{
    // TODO
}

void AdminHandler::kickName(const std::string &name A_UNUSED)
{
    // TODO
}

void AdminHandler::ban(int playerId A_UNUSED)
{
    // TODO
}

void AdminHandler::banName(const std::string &name A_UNUSED)
{
    // TODO
}

void AdminHandler::unban(int playerId A_UNUSED)
{
    // TODO
}

void AdminHandler::unbanName(const std::string &name A_UNUSED)
{
    // TODO
}

void AdminHandler::mute(int playerId A_UNUSED, int type A_UNUSED,
                        int limit A_UNUSED)
{
    // TODO
}

void AdminHandler::warp(std::string map A_UNUSED,
                        int x A_UNUSED, int y A_UNUSED)
{
    // TODO
}

} // namespace ManaServ
